<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://involvz.com/
 * @since      1.0.0
 *
 * @package    tagsyncer
 * @subpackage tagsyncer/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    tagsyncer
 * @subpackage tagsyncer/admin
 * @author     Involvz <data@involvz.com>
 */
class tagsyncer_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tagsyncer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tagsyncer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/tagsyncer-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tagsyncer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tagsyncer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/tagsyncer-admin.js', array( 'jquery' ), $this->version, false );

	}
	public function display_gtm_notice() {
		$options = get_option('tagsyncer_tab1_option_name');
		$gtm_id = isset($options['gtm_id']) ? esc_attr($options['gtm_id']) : '';
		if (empty($gtm_id)) {
			?>
            <div class="notice notice-error">
        		<p><?php esc_html_e('Google Tag Manager ID is not set. Please complete the GTM plugin configuration.', 'tag-syncer'); ?></p>
            </div>
            <?php
		}
	}
	

	public function tagsyncer_add_google_tag_manager_menu() {
		add_menu_page(
			'Google Tag Manager',
			'Google Tag Manager',
			'manage_options',
			'google-tag-manager-settings',
			array($this, 'tagsyncer_google_tag_manager_settings_page'),
			'dashicons-tag'
		);
	}

	function tagsyncer_google_tag_manager_settings_page() {
		?>
			<div class="wrap" id="tagsyncer-wrap">
				<?php settings_errors(); ?>
				<h2 class="tagsyncer-nav-tab-wrapper">
				    <a class="tagsyncer-nav-tab tagsyncer-nav-tab-active" href="#tagsyncer-tab1">General Settings</a>
                    <a class="tagsyncer-nav-tab" href="#tagsyncer-tab2">Scroll Tracking Settings</a>
                    <a class="tagsyncer-nav-tab" href="#tagsyncer-tab3">Integrations</a>
                    <a class="tagsyncer-nav-tab" href="#tagsyncer-tab4">Credits</a>
                </h2>
				<div id="tagsyncer-tab1" class="tagsyncer-tab-content">
					<form method="post" action="options.php">
					<?php
                    settings_fields('tagsyncer_google_tag_manager_settings1');
                    do_settings_sections('tagsyncer_google_tag_manager_settings1');
                    wp_nonce_field('tagsyncer_google_tag_manager_nonce_action', 'tagsyncer_google_tag_manager_nonce_field'); // Add this line
                    submit_button();
                    ?>
					</form>
				</div>

				<div id="tagsyncer-tab2" class="tagsyncer-tab-content">
					<form method="post" action="options.php">
						<?php
						settings_fields('tagsyncer_google_tag_manager_settings2');
						do_settings_sections('tagsyncer_google_tag_manager_settings2');
						wp_nonce_field('tagsyncer_google_tag_manager_nonce_action', 'tagsyncer_google_tag_manager_nonce_field'); // Add this line
						submit_button();
						?>
					</form>
				</div>

				<div id="tagsyncer-tab3" class="tagsyncer-tab-content">
					<form method="post" action="options.php">
						<?php
						settings_fields('tagsyncer_google_tag_manager_settings3');
						do_settings_sections('tagsyncer_google_tag_manager_settings3');
						wp_nonce_field('tagsyncer_google_tag_manager_nonce_action', 'tagsyncer_google_tag_manager_nonce_field'); // Add this line
						submit_button();
						?>
					</form>
				</div>
				<div id="tagsyncer-tab4" class="tagsyncer-tab-content">
					<?php
					do_settings_sections('tagsyncer_google_tag_manager_settings4');
					?>
				</div>
			</div>
		<!-- <div class="wrap" id="tagsyncer-wrap">
			<h2>Google Tag Manager Settings</h2>
			<?php //settings_errors(); ?>
	
			<h2 class="tagsyncer-nav-tab-wrapper">
				<a class="tagsyncer-nav-tab tagsyncer-nav-tab-active" href="#general">General</a>
				<a class="tagsyncer-nav-tab" href="#scroll-tracking">Scroll Tracking</a>
				<a class="tagsyncer-nav-tab" href="#integration">Integration</a>
			</h2>
	
			<form method="post" action="options.php">
				<?php
				// settings_fields('google_tag_manager_options');
				// do_settings_sections('tagsyncer_google_tag_manager_settings');
				// submit_button();
				?>
			</form>
		</div> -->
		<style>
			.tagsyncer-tab-content:not(.tagsyncer-nav-tab-active) {
				display: none;
			}
		</style>
		<script>
            jQuery(document).ready(function($) {
                $('.tagsyncer-nav-tab-wrapper a').on('click', function(e) {
                    e.preventDefault();
                    $('.tagsyncer-nav-tab-wrapper a').removeClass('tagsyncer-nav-tab-active');
                    $(this).addClass('tagsyncer-nav-tab-active');
                    $('.tagsyncer-tab-content').hide();
                    $($(this).attr('href')).show();
                });

                // Show the default tab on page load
				$('#tagsyncer-tab1').show();
            });
        </script>
		<script>
			// jQuery(document).ready(function($) {
			// 	$('.tagsyncer-nav-tab').click(function(event) {
			// 		event.preventDefault();
			// 		var tab = $(this).attr('href');
			// 		$('.tagsyncer-nav-tab').removeClass('tagsyncer-nav-tab-active');
			// 		$(this).addClass('tagsyncer-nav-tab-active');
			// 		$('form').hide();
			// 		$(tab + '-form').show();
			// 	});

			// 	// Initialize on the "General" tab
			// 	$('.tagsyncer-nav-tab-general').click();
			// });
		</script>
		<?php
	}
	
	function tagsyncer_google_tag_manager_register_settings() {
		// Tab 1
		register_setting(
			'tagsyncer_google_tag_manager_settings1',
			'tagsyncer_tab1_option_name',
			array(
				'sanitize_callback' => array($this, 'sanitize_tab1_settings'), // Add sanitization callback
			)
		);
		add_settings_section(
			'general_section',
			'General Settings',
			array($this, 'general_section_callback'),
			'tagsyncer_google_tag_manager_settings1'
		);
		add_settings_field(
			'gtm_enable',
			'Enable Google Tag Manager',
			array($this, 'tagsyncer_gtm_enable_callback'),
			'tagsyncer_google_tag_manager_settings1',
			'general_section'
		);
		add_settings_field(
			'gtm_id',
			'Google Tag Manager ID',
			array($this, 'tagsyncer_gtm_id_callback'),
			'tagsyncer_google_tag_manager_settings1',
			'general_section'
		);
	
		// Tab 2
		register_setting(
			'tagsyncer_google_tag_manager_settings2',
			'tagsyncer_tab2_option_name',
			array(
				'sanitize_callback' => array($this, 'sanitize_tab2_settings'),
			)
		);
		add_settings_section(
			'scroll_tracking_section',
			'Scroll Tracking Settings',
			array($this, 'scroll_tracking_section_callback'),
			'tagsyncer_google_tag_manager_settings2'
		);
		add_settings_field(
			'scroll_tracking_enable',
			'Enable Scroll Tracking',
			array($this, 'scroll_tracking_enable_callback'),
			'tagsyncer_google_tag_manager_settings2',
			'scroll_tracking_section'
		);
		add_settings_field(
			'scroll_tracking_min_distance',
			'Minimum Distance',
			array($this, 'scroll_tracking_min_distance_callback'),
			'tagsyncer_google_tag_manager_settings2',
			'scroll_tracking_section'
		);
	
		// Tab 3
		register_setting(
			'tagsyncer_google_tag_manager_settings3',
			'tagsyncer_tab3_option_name',
			array(
				'sanitize_callback' => array($this, 'sanitize_tab3_settings'),
			)
		);
		add_settings_section(
			'integration_section',
			'Integrations',
			array($this, 'integration_section_callback'),
			'tagsyncer_google_tag_manager_settings3'
		);
		add_settings_field(
			'cf7_enable',
			'Enable CF7 Tracking',
			array($this, 'cf7_enable_callback'),
			'tagsyncer_google_tag_manager_settings3',
			'integration_section'
		);
		add_settings_field(
			'elform_enable',
			'Enable Elementor Form Tracking',
			array($this, 'elform_enable_callback'),
			'tagsyncer_google_tag_manager_settings3',
			'integration_section'
		);
		add_settings_field(
			'wc_track_enable',
			'Enable Woocommerce Tracking',
			array($this, 'wc_track_enable_callback'),
			'tagsyncer_google_tag_manager_settings3',
			'integration_section'
		);	
		// Tab 4
		add_settings_section(
			'credits_section',
			'Credits',
			array($this, 'credits_section_callback'),
			'tagsyncer_google_tag_manager_settings4'
		);
	}
	
	// Sanitization callbacks for settings
	public function sanitize_tab1_settings($input) {
		$gtm_id = isset($input['gtm_id']) ? sanitize_text_field($input['gtm_id']) : '';
		
		// Check if GTM ID is empty and send an email if it is
		if (empty($gtm_id)) {
			$this->send_gtm_missing_email();
		}
		
		return array_map('sanitize_text_field', $input);
	}
	
	private function send_gtm_missing_email() {
		$admin_email = get_option('admin_email');
		$site_url = get_site_url();
		$plugin_settings_url = $site_url . '/wp-admin/admin.php?page=google-tag-manager-settings';
		
		$subject = '⚠️ Alert: Google Tag Manager ID Missing';
		$message = '<p>Hi,</p>';
		$message .= '<p>It seems the Google Tag Manager (GTM) ID field in your TagSyncer plugin is empty. Please update it in the plugin settings to ensure proper tracking.</p>';
		$message .= '<br>';
		$message .= '<p><a href="' . $plugin_settings_url . '" style="display: inline-block; padding: 10px 20px; font-size: 16px; color: #ffffff; background-color: #2a4680; text-decoration: none; border-radius: 5px;">Update Now</a></p>';
		$message .= '<br>';
		$message .= '<p>For assistance, feel free to contact us.</p>';
		$message .= '<p>Best regards,<br>The TagSyncer Team</p>';
		
		$headers = array('Content-Type: text/html; charset=UTF-8');
		
		// Send the notification email
		wp_mail($admin_email, $subject, $message, $headers);
	}
	
	
	
	public function sanitize_tab2_settings($input) {
		$input['scroll_tracking_min_distance'] = absint($input['scroll_tracking_min_distance']); // Ensure it's an integer
		return $input;
	}
	
	public function sanitize_tab3_settings($input) {
		$input = is_array($input) ? $input : [];
		$default_settings = array(
			'cf7_enable' => 0,          
			'elform_enable' => 0,      
			'wc_track_enable' => 0,    
		);
		$sanitized_settings = array_map('sanitize_text_field', array_merge($default_settings, $input));
		return $sanitized_settings;
	}
	
	function validate_tab1_settings($input) {
		if (empty($input['gtm_id'])) {
			$admin_email = get_option('admin_email');
			$site_url = get_site_url();
			$plugin_settings_url = $site_url . '/wp-admin/admin.php?page=google-tag-manager-settings';
			$subject = '⚠️ Alert: Google Tag Manager ID is empty';
			$message = '<p>Hi,</p>';
			$message .= '<p>The Google Tag Manager (GTM) ID field in your TagSyncer plugin is empty. Please update it in the plugin settings to ensure proper tracking.</p>';
			$message .= '<br>';
			$message .= '<p><a href="' . $plugin_settings_url . '" style="display: inline-block; padding: 10px 20px; font-size: 16px; color: #ffffff; background-color: #2a4680; text-decoration: none; border-radius: 5px;">Update Now</a></p>';
			$message .= '<br>';
			$message .= '<p>For assistance, feel free to contact us.</p>';
			$message .= '<p>Best regards,<br>The TagSyncer Team</p>';
			$headers = array('Content-Type: text/html; charset=UTF-8');
			wp_mail($admin_email, $subject, $message, $headers);
		}
	}
	
	function general_section_callback() {
		echo '<p>General settings for Google Tag Manager.</p>';
	}
	
	function tagsyncer_gtm_enable_callback() {
		$options = get_option('tagsyncer_tab1_option_name');
		$gtm_enable = isset($options['gtm_enable']) ? $options['gtm_enable'] : 0; // Default to 0 if not set
		echo '<input type="checkbox" name="tagsyncer_tab1_option_name[gtm_enable]" ' . checked(1, $gtm_enable, false) . ' value="1" />';
	}
	function tagsyncer_gtm_id_callback() {
		$options = get_option('tagsyncer_tab1_option_name');
		$gtm_id = isset($options['gtm_id']) ? esc_attr($options['gtm_id']) : ''; // Default to an empty string if not set
		echo '<input type="text" name="tagsyncer_tab1_option_name[gtm_id]" value="' . esc_attr( $gtm_id ) . '" placeholder="GTM-XXXXXXXX" />';
	}

	function scroll_tracking_section_callback() {
		echo '<p>Scroll tracking settings for Google Tag Manager.</p>';
	}
	
	function scroll_tracking_enable_callback() {
		$options = get_option('tagsyncer_tab2_option_name');
		$scroll_tracking_enable = isset($options['scroll_tracking_enable']) ? $options['scroll_tracking_enable'] : 0; // Default to 0 if not set
		echo '<input type="checkbox" name="tagsyncer_tab2_option_name[scroll_tracking_enable]" ' . checked(1, $scroll_tracking_enable, false) . ' value="1" />';
	}
	
	function scroll_tracking_min_distance_callback() {
		$options = get_option('tagsyncer_tab2_option_name');
		$scroll_tracking_min_distance = isset($options['scroll_tracking_min_distance']) ? $options['scroll_tracking_min_distance'] : 150; // Default to 150 if not set
		echo '<input type="number" name="tagsyncer_tab2_option_name[scroll_tracking_min_distance]" value="' . esc_attr($scroll_tracking_min_distance) . '" />';
	}
	
	function integration_section_callback() {
		echo '<p>Google Tag Manager Integrations.</p>';
	}
	function credits_section_callback() {
		echo '<p>' . esc_html__('Some info about the author of this plugin.', 'tag-syncer') . '</p>';
		echo '<table class="form-table" role="presentation" style="">
			<tbody>
				<tr>
					<th scope="row"><label for="gtm4wp-admin-group-datalayer-info">Author</label></th>
					<td>
						<strong>Team Involvz</strong><br>
						Website: <a href="http://tagsyncer.com/" target="_blank" rel="noopener">tagsyncer.com</a><br>
						<a href="https://www.linkedin.com/in/m-waqar-web-dev/" target="_blank" rel="noopener">Admin LinkedIn</a><br>
						<a href="https://www.linkedin.com/in/wasim-t/" target="_blank" rel="noopener">Involvz Marketing</a>
					</td>
				</tr>
			</tbody>
		</table>';
	}
	function cf7_enable_callback() {
		$options = get_option('tagsyncer_tab3_option_name');
		$cf7_enable = isset($options['cf7_enable']) ? $options['cf7_enable'] : 0; // Default to 0 if not set
		echo '<input type="checkbox" name="tagsyncer_tab3_option_name[cf7_enable]" ' . checked(1, $cf7_enable, false) . ' value="1" /> <br>Check this to fire dataLayer events after Contact Form 7 submissions (supported events: invalid input, spam detected, form submitted, form submitted and mail sent, form submitted and mail send failed).';
	}
	function elform_enable_callback() {
		$options = get_option('tagsyncer_tab3_option_name');
		$elform_enable = isset($options['elform_enable']) ? $options['elform_enable'] : 0; // Default to 0 if not set
		echo '<input type="checkbox" name="tagsyncer_tab3_option_name[elform_enable]" ' . checked(1, $elform_enable, false) . ' value="1" /> <br>Check this to fire dataLayer events after Elementor Form submissions (supported events: form submitted).';
	}
	function wc_track_enable_callback() {
		$options = get_option('tagsyncer_tab3_option_name');
		$wc_track_enable = isset($options['wc_track_enable']) ? $options['wc_track_enable'] : 0; // Default to 0 if not set
		echo '<input type="checkbox" name="tagsyncer_tab3_option_name[wc_track_enable]" ' . checked(1, $wc_track_enable, false) . ' value="1" /> <br>Check this to fire dataLayer events for Woocommerce.';
	}

	function tagsyncer_google_tag_manager_save_settings() {
		// Check if the form was submitted and the nonce field is set
		if (isset($_POST['submit_tagsyncer_google_tag_manager_settings1']) && isset($_POST['tagsyncer_google_tag_manager_nonce_field'])) {
	
			// Unsanitize and sanitize the nonce field
			$nonce = sanitize_text_field(wp_unslash($_POST['tagsyncer_google_tag_manager_nonce_field'])); // Remove slashes and sanitize
			
			// Verify the nonce to prevent CSRF attacks
			if (wp_verify_nonce($nonce, 'tagsyncer_google_tag_manager_nonce_action')) {
				
				// Get the options and the GTM ID
				$options = get_option('tagsyncer_tab1_option_name');
				$gtm_id = isset($options['gtm_id']) ? esc_attr($options['gtm_id']) : '';
	
				// If the GTM ID is empty, notify the admin
				if (empty($gtm_id)) {
					$admin_email = get_option('admin_email');
					$site_url = get_site_url();
					$plugin_settings_url = $site_url . '/wp-admin/admin.php?page=google-tag-manager-settings';
					$subject = '⚠️ Alert: Google Tag Manager ID is empty';
					$message = '<p>Hi,</p>';
					$message .= '<p>The Google Tag Manager (GTM) ID field in your TagSyncer plugin is empty. Please update it in the plugin settings to ensure proper tracking.</p>';
					$message .= '<br>';
					$message .= '<p><a href="' . $plugin_settings_url . '" style="display: inline-block; padding: 10px 20px; font-size: 16px; color: #ffffff; background-color: #2a4680; text-decoration: none; border-radius: 5px;">Update Now</a></p>';
					$message .= '<br>';
					$message .= '<p>For assistance, feel free to contact us.</p>';
					$message .= '<p>Best regards,<br>The TagSyncer Team</p>';
					$headers = array('Content-Type: text/html; charset=UTF-8');
					wp_mail($admin_email, $subject, $message, $headers);
				}				
			} else {
				// Nonce verification failed
				die('Nonce verification failed.');
			}
		}
	}
	
	
		
}
