<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://involvz.com/
 * @since      1.0.0
 *
 * @package    tagsyncer
 * @subpackage tagsyncer/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    tagsyncer
 * @subpackage tagsyncer/public
 * @author     Involvz <data@involvz.com>
 */
class tagsyncer_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tagsyncer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tagsyncer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/tagsyncer-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tagsyncer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tagsyncer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/tagsyncer-public.js', array( 'jquery' ), $this->version, false );

	}

	// public function save_google_tag_manager_script() {

    //     $options = get_option('google_tag_manager_settings');
		
    //     if (!empty($options['gtm_id']) && $options['gtm_enable']) {
    //         $gtm_id = sanitize_text_field($options['gtm_id']);
    //         $script = '<!-- Google Tag Manager -->';
    //         $script .= '<script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({"gtm.start":new Date().getTime(),event:"gtm.js"});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!="dataLayer"?"&l="+l:"";j.async=true;j.src="https://www.googletagmanager.com/gtm.js?id="+i+dl;f.parentNode.insertBefore(j,f);})(window,document,"script","dataLayer","' . $gtm_id . '");</script>';
    //         $script .= '<!-- End Google Tag Manager -->';

    //         // Add the script to the site header
    //         add_action('wp_head', function () use ($script) {
    //             echo $script;
    //         });
    //     }
    // }

	public function save_google_tag_manager_script() {
		$options = get_option('google_tag_manager_settings');
		
		if (!empty($options['gtm_id']) && $options['gtm_enable']) {
			// Sanitize and get the GTM IDs from options
			$gtm_ids = array_map('sanitize_text_field', explode(',', $options['gtm_id']));
			
			// Initialize an empty variable to hold all GTM scripts
			$scripts = '';
			
			// Loop through each GTM ID and create a unique script
			foreach ($gtm_ids as $index => $gtm_id) {
				$data_layer_name = ($index === 0) ? 'dataLayer' : 'dataLayer' . ($index + 1); // dataLayer, dataLayer2, dataLayer3, etc.
				$script = '<!-- Google Tag Manager -->';
				$script .= '<script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({"gtm.start":new Date().getTime(),event:"gtm.js"});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!="' . $data_layer_name . '"?"&l="+l:"";j.async=true;j.src="https://www.googletagmanager.com/gtm.js?id="+i+dl;f.parentNode.insertBefore(j,f);})(window,document,"script","' . $data_layer_name . '","' . $gtm_id . '");</script>';
				$script .= '<!-- End Google Tag Manager -->';
			
				// Append the generated script to the combined scripts variable
				$scripts .= $script . "\n";
			}
			
			// Add the combined scripts to the site header securely
			add_action('wp_head', function () use ($scripts) {
				echo wp_kses($scripts, array(
					'script' => array(
						'src' => true,
						'async' => true,
						'type' => true
					)
				));
			});
		}
	}
	function tagsyncer_google_tag_manager_scroll_tracking_script() {
		$options = get_option('google_tag_manager_settings');
		$scroll_enable = isset($options['scroll_tracking_enable']) ? $options['scroll_tracking_enable'] : 0;
	
		if ($scroll_enable) {
			
			$gtm_id = isset($options['gtm_id']) ? esc_attr($options['gtm_id']) : '';
	
			if (!empty($gtm_id)) {
				echo '<script>
				function trackScrolling() {
					var scrollDepth = 0;
					var minScrollDistance = 150; // Adjust this value as needed
				  
					// Set some flags for tracking & execution
					var timer = 0;
					var scroller = false;
					var endContent = false;
					var didComplete = false;
				  
					// Set some time variables to calculate reading time
					var startTime = new Date();
					var beginning = startTime.getTime();
					var totalTime = 0;
				  
					window.addEventListener("scroll", function () {
					  var scrollPosition = window.scrollY;
					  if (scrollPosition >= minScrollDistance) {
						// Push a custom event to the GTM data layer
						window.dataLayer = window.dataLayer || [];
						window.dataLayer.push({
						  event: "scroll_tracking",
						  scrollDepth: scrollPosition,
						});
				  
						// Reset scrollDepth to avoid sending duplicate events
						scrollDepth = scrollPosition + minScrollDistance;
					  }
				  
					  // Track user scroll for reading time calculation
					  if (!scroller) {
						timer = setTimeout(function () {
						  if (!endContent) {
							totalTime += 100;
							// Push a custom event for scroll tracking
							window.dataLayer = window.dataLayer || [];
							window.dataLayer.push({
							  event: "scroll_read_time",
							  scrollTime: totalTime,
							});
						  }
						}, 100);
					  }
				  
					  if (scrollPosition === 0) {
						clearTimeout(timer);
						scroller = false;
					  } else {
						scroller = true;
					  }
				  
					  if (
						window.innerHeight + scrollPosition >=
						document.documentElement.scrollHeight
					  ) {
						// User has reached the end of the content
						endContent = true;
				  
						if (!didComplete) {
						  var endTime = new Date();
						  var end = endTime.getTime();
						  totalTime = end - beginning;
				  
						  // Push a custom event for scroll tracking
						  window.dataLayer = window.dataLayer || [];
						  window.dataLayer.push({
							event: "scroll_read_time_complete",
							scrollTime: totalTime,
						  });
				  
						  didComplete = true;
						}
					  }
					});
				  }
				  
				  // Call the function to start tracking scrolling
				  trackScrolling();				  
				</script>';
			}
		}
	}

}
