<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://involvz.com/
 * @since      1.0.0
 *
 * @package    tagsyncer
 * @subpackage tagsyncer/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    tagsyncer
 * @subpackage tagsyncer/public
 * @author     Involvz <data@involvz.com>
 */
class tagsyncer_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tagsyncer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tagsyncer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/tagsyncer-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in tagsyncer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The tagsyncer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( 'gtm-enhanced-js', plugin_dir_url( __FILE__ ) . 'js/tagsyncer-public.js', array( 'jquery' ), $this->version, false );


		// Get WooCommerce cart items and totals
		if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
			$cart_items = array();
			if ( WC()->cart->get_cart() ) {
				foreach ( WC()->cart->get_cart() as $cart_item ) {
					$cart_items[] = array(
						'id' => $cart_item['product_id'],
						'name' => $cart_item['data']->get_name(),
						'quantity' => $cart_item['quantity'],
						'total_price' => $cart_item['line_total']
					);
				}
			}
			
			// Prepare cart and currency data
			$cart_data = array(
				'cartData' => $cart_items,
				'gtmCurrency' => get_woocommerce_currency(), // Gets the store currency
			);

			// Pass the data to JavaScript via wp_localize_script
			wp_localize_script('gtm-enhanced-js', 'cartAndCurrencyData', $cart_data);
		}
	}


	
	// public function save_google_tag_manager_script() {

    //     $options = get_option('tagsyncer_tab1_option_name');
		
    //     if (!empty($options['gtm_id']) && $options['gtm_enable']) {
    //         $gtm_id = sanitize_text_field($options['gtm_id']);
    //         $script = '<!-- Google Tag Manager -->';
    //         $script .= '<script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({"gtm.start":new Date().getTime(),event:"gtm.js"});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!="dataLayer"?"&l="+l:"";j.async=true;j.src="https://www.googletagmanager.com/gtm.js?id="+i+dl;f.parentNode.insertBefore(j,f);})(window,document,"script","dataLayer","' . $gtm_id . '");</script>';
    //         $script .= '<!-- End Google Tag Manager -->';

    //         // Add the script to the site header
    //         add_action('wp_head', function () use ($script) {
    //             echo $script;
    //         });
    //     }
    // }

	public function save_google_tag_manager_script() {
		$options = get_option('tagsyncer_tab1_option_name');
	
		// Check if GTM ID exists and is enabled
		if (!empty($options['gtm_id']) && !empty($options['gtm_enable'])) {
			// Get GTM IDs, trim any whitespace, and split by comma (allowing multiple GTM IDs)
			$gtm_ids = array_map('sanitize_text_field', array_map('trim', explode(',', $options['gtm_id'])));
	
			// Initialize an empty string to store the combined script
			$combined_scripts = '';
	
			// Loop through each GTM ID and create a unique script
			foreach ($gtm_ids as $index => $gtm_id) {
				// Generate dataLayer name for each GTM ID
				$data_layer_name = ($index === 0) ? 'dataLayer' : 'dataLayer' . ($index + 1);
	
				// Add dataLayer initialization for each GTM ID
				$data_layer_script = "<script>window.{$data_layer_name} = window.{$data_layer_name} || [];</script>";
	
				// Generate GTM script for each GTM ID
				$gtm_script = '<!-- Google Tag Manager -->';
				$gtm_script .= '<script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({"gtm.start":new Date().getTime(),event:"gtm.js"});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!="' . $data_layer_name . '"?"&l="+l:"";j.async=true;j.src="https://www.googletagmanager.com/gtm.js?id="+i+dl;f.parentNode.insertBefore(j,f);})(window,document,"script","' . $data_layer_name . '","' . $gtm_id . '");</script>';
				$gtm_script .= '<!-- End Google Tag Manager -->';
	
				// Append the current GTM script and dataLayer initialization to the combined scripts
				$combined_scripts .= $data_layer_script . "\n" . $gtm_script . "\n";
			}
	
			// Add the combined scripts to the site header
			add_action('wp_head', function () use ($combined_scripts) {
				echo wp_kses( $combined_scripts, array(
					'script' => array(
						'src' => true,
						'async' => true,
						'type' => true,
						'defer' => true,
					),
				) );
			});
		}
	}
	
	
	
	
	
	

	function tagsyncer_google_tag_manager_scroll_tracking_script() {
		$options1 = get_option('tagsyncer_tab1_option_name');
		$options2 = get_option('tagsyncer_tab2_option_name');
		$options3 = get_option('tagsyncer_tab3_option_name');
		$scroll_enable = isset($options2['scroll_tracking_enable']) ? $options2['scroll_tracking_enable'] : 0;
		$scroll_tracking_min_distance = isset($options2['scroll_tracking_min_distance']) ? $options2['scroll_tracking_min_distance'] : 150;
		$gtm_id = isset($options1['gtm_id']) ? esc_attr($options1['gtm_id']) : '';

		if ( $scroll_enable  && !empty($gtm_id) ) {		
			echo "<script>
			console.log('Gtag');
			
			var debugMode = false;
			// Default time delay before checking location
			var callBackTime = 100;
			
			// # px before tracking a reader
			var readerLocation = '" . esc_js( $scroll_tracking_min_distance ) . "';
			
			// Set some flags for tracking & execution
			var timer = 0;
			var scroller = false;
			var endContent = false;
			var didComplete = false;
			
			// Set some time variables to calculate reading time
			var startTime = new Date();
			var beginning = startTime.getTime();
			var totalTime = 0;
			
			// Track the article load
			if (!debugMode && window.dataLayer) {
				window.dataLayer.push({
				event: 'ArticleLoaded'
				});
			}
			
			// Track scrolling and location
			function trackLocation() {
				var bottom = jQuery(window).height() + jQuery(window).scrollTop();
				var height = jQuery(document).height();

				var windowHeight = jQuery(window).height();
				var documentHeight = jQuery(document).height();
				var scrollTop = jQuery(window).scrollTop();

				// Calculate scroll depth in percentage
				scrollDepth = Math.round((scrollTop / (documentHeight - windowHeight)) * 100);

				// Push scroll depth event to data layer
				if (scrollDepth >= 25) {
					pushScrollDepthEvent(scrollDepth);
				}

				// If user starts to scroll, send an event
				if (bottom > readerLocation && !scroller) {
					var currentTime = new Date();
					var scrollStart = currentTime.getTime();
					var timeToScroll = Math.round((scrollStart - beginning) / 1000);
				
					if (!debugMode && window.dataLayer) {
						window.dataLayer.push({
						event: 'StartReading',
						timeToScroll: timeToScroll
						});
					} else {
						console.log('Started reading after ' + timeToScroll + ' seconds');
					}
				
					scroller = true;
				}
			
				// If user has hit the bottom of the content, send an event
				if (bottom >= jQuery('main').scrollTop() + jQuery('main').innerHeight() && !endContent) {
				var currentTime = new Date();
				var contentScrollEnd = currentTime.getTime();
				var timeToContentEnd = Math.round((contentScrollEnd - scrollStart) / 1000);
			
				if (!debugMode && window.dataLayer) {
					window.dataLayer.push({
					event: 'ContentBottom',
					timeToContentEnd: timeToContentEnd
					});
				} else {
					console.log('Reached end of content after ' + timeToContentEnd + ' seconds');
				}
			
				endContent = true;
				}
			
				// If user has hit the bottom of the page, send an event
				if (bottom >= height && !didComplete) {
				var currentTime = new Date();
				var end = currentTime.getTime();
				totalTime = Math.round((end - scrollStart) / 1000);
			
				if (!debugMode && window.dataLayer) {
					if (totalTime < 60) {
					window.dataLayer.push({
						event: 'PageBottom',
						readerType: 'Scanner'
					});
					} else {
					window.dataLayer.push({
						event: 'PageBottom',
						readerType: 'Reader'
					});
					}
				} else {
					console.log('Reached the bottom of the page after ' + totalTime + ' seconds');
				}
			
				didComplete = true;
				}
			}
			// Push scroll depth event to data layer
			function pushScrollDepthEvent(depth) {
				if (!debugMode && window.dataLayer) {
					window.dataLayer.push({
						event: 'ScrollDepth',
						'gtm.scrollThreshold': depth,
						'gtm.scrollUnits': 'percent',
						'gtm.scrollDirection': 'vertical'
					});
				}
			}

			// Track the scrolling and track location
			jQuery(window).scroll(function () {
				if (timer) {
				clearTimeout(timer);
				}
				// Use a buffer so we don’t call trackLocation too often.
				timer = setTimeout(trackLocation, callBackTime);
			});		  
			</script>";
		
		}
		$cf7_enable = isset($options3['cf7_enable']) ? $options3['cf7_enable'] : 0;

		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

		if (is_plugin_active('contact-form-7/wp-contact-form-7.php')) {
			
			if ($cf7_enable && !empty($gtm_id)) {
				// Add GTM scripts for Contact Form 7
				echo "<script>
					// Function to set cookie
					function setCookie(name, value) {
						var date = new Date();
						date.setTime(date.getTime() + (90 * 24 * 60 * 60 * 1000)); // 90 days
						var expires = '; expires=' + date.toUTCString();
						document.cookie = name + '=' + value + expires + '; path=/';
					}
					function getCookie(name) {
						var nameEQ = name + '=';
						var ca = document.cookie.split(';');
						for (var i = 0; i < ca.length; i++) {
							var c = ca[i];
							while (c.charAt(0) == ' ') c = c.substring(1, c.length);
							if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length, c.length);
						}
						return null;
					}
					var getUrlParameter = function getUrlParameter(sParam) {
						var sPageURL = window.location.search.substring(1),
							sURLVariables = sPageURL.split('&'),
							sParameterName,
							i;
					
						for (i = 0; i < sURLVariables.length; i++) {
							sParameterName = sURLVariables[i].split('=');
					
							if (sParameterName[0] === sParam) {
								return sParameterName[1] === undefined ? true : decodeURIComponent(sParameterName[1]);
							}
						}
						return false;
					};
					function populateHiddenField() {
						var utmSourceParam = getUrlParameter('utm_source');
						var utmMediumParam = getUrlParameter('utm_medium');
						var utmCampaignParam = getUrlParameter('utm_campaign');
						// If URL parameters exist, update cookies
						if (utmSourceParam) setCookie('utm_source', utmSourceParam);
						if (utmMediumParam) setCookie('utm_medium', utmMediumParam);
						if (utmCampaignParam) setCookie('utm_campaign', utmCampaignParam);

						var utmSourceField = document.getElementById('utm_source');
						var utmMediumField = document.getElementById('utm_medium');
						var utmCampaignField = document.getElementById('utm_campaign');

						if (utmSourceField) {
							var utmSource = getCookie('utm_source');
							console.log(utmSource);
							utmSourceField.value = utmSource || '';
						}
						if (utmMediumField) {
							var utmMedium = getCookie('utm_medium');
							console.log(utmMedium);
							utmMediumField.value = utmMedium || '';
						}
						if (utmCampaignField) {
							var utmCampaign = getCookie('utm_campaign');
							console.log(utmCampaign);
							utmCampaignField.value = utmCampaign || '';
						}
						// Assuming you have a hidden field with IDs 'utm_source', 'utm_medium', 'utm_campaign'
						// document.getElementById('utm_source').value = utmSource || '';
						// document.getElementById('utm_medium').value = utmMedium || '';
						// document.getElementById('utm_campaign').value = utmCampaign || '';
					}
					// Call the function after a delay when the document is ready
					document.addEventListener('DOMContentLoaded', function () {
						// Delay in milliseconds (e.g., 2000 for 2 seconds)
						var delay = 2000;
					
						// Set a timeout to call the function after the specified delay
						setTimeout(function () {
							populateHiddenField();
						}, delay);
					});
					// Track Contact Form 7 submission
					document.addEventListener('wpcf7mailsent', function(event) {
						if (window.dataLayer) {
							window.dataLayer.push({
								event: 'cf7FormSubmitted',
								'formId': event.detail.contactFormId,
								'formData': event.detail.inputs
							});
						}
					});
					// Track Contact Form 7 mail failed
					document.addEventListener('wpcf7mailfailed', function(event) {
						if (window.dataLayer) {
							window.dataLayer.push({
								event: 'cf7MailFailed',
								'formId': event.detail.contactFormId,
								'formData': event.detail.inputs
							});
						}
					});
					// Track Contact Form 7 spam detection
					document.addEventListener('wpcf7spam', function(event) {
						if (window.dataLayer) {
							window.dataLayer.push({
								event: 'cf7SpamDetected',
								'formId': event.detail.contactFormId,
								'formData': event.detail.inputs
							});
						}
					});
				</script>";
			}
		}
		$elform_enable = isset($options3['elform_enable']) ? $options3['elform_enable'] : 0;	
		if (is_plugin_active('elementor/elementor.php')) {
			if ($elform_enable && !empty($gtm_id)) {
				// Add GTM scripts for Elementor forms
				echo "<script>
					// Track Elementor form submission successful
					jQuery(document).ready(function($) {
						jQuery(document).on('submit_success', function(event, formID, fieldsData) {
							console.log(event);
							// alert(formID);
							// alert(fieldsData);
							window.dataLayer = window.dataLayer || [];
							window.dataLayer.push({
								event: 'formSubmissionSucess',
								formID: formID,
								formData: fieldsData
							});
						});
					});
				</script>";
			}
		}
	}
	public function custom_form_submission_handler($record, $handler) {
		
		if ($handler->is_success) {
			// var_dump($record->get_form_settings());
			// exit();
			$form_id = $record->get_form_settings('id');	
			$fields = $record->get_formatted_fields();
	
			if (function_exists('wp_json_encode')) {
				echo '<script>';
				echo 'dataLayer = dataLayer || [];';
				echo 'dataLayer.push({';
				echo '  "event": "form_submission",';
				echo '  "formID": "' . esc_js( $form_id ) . '",';
				echo '  "formData": ' . wp_json_encode($fields);
				echo '});';
				echo '</script>';
			}
		}
	}
	public function tagsyncer_add_gta_prod_data_hidden_field() {
		global $product;
		// Get product data
		$item_id = $product->get_sku() ? $product->get_sku() : $product->get_id();
		$item_name = $product->get_name();
		$product_type = $product->get_type();
		$remarketing_id = $product->get_id();
		$product_sku = $product->get_sku();
		$product_categories = array();
		$product_brand = '';
		$coupon = ''; // Placeholder for coupon
		$discount = 0; // Placeholder for discount
		$affiliation = 'Your Affiliation'; // Placeholder for affiliation
		$index = 0; // Placeholder for index
		// Get product categories
		$categories = get_the_terms( $product->get_id(), 'product_cat' );
		if ( $categories && ! is_wp_error( $categories ) ) {
			foreach ( $categories as $key => $category ) {
				$product_categories[ $key ] = $category->name;
			}
		}
		// Create the product data array
		$product_data = array(
			'item_id' => $item_id,
			'item_name' => $item_name,
			'item_brand' => $product_brand,
			'item_list_id' => 'view_item_list',
			'item_list_name' => 'View Item List',
			'price' => round( (float) wc_get_price_to_display( $product ), 2 ),
			'quantity' => 1
		);
		// Add multiple category keys
		foreach ( $product_categories as $key => $category_name ) {
			$product_data_key = $key === 0 ? 'item_category' : 'item_category_' . ($key + 1);
			$product_data[ $product_data_key ] = $category_name;
		}
		// Convert the product data array to JSON
		$product_data_json = wp_json_encode($product_data);
		// Output the hidden field
		echo '<input type="hidden" name="gta_prod_data" value="' . esc_attr( $product_data_json ) . '">';
	}
	public function tagsyncer_gtmwc_wp_header_enhanced_wc($echo = true){
		global $tagsyncer_datalayer_data, $woocommerce;
	}
	function tagsyncer_gtmwp_frontend_datalayer($data) {
		return $data;
	}
}
	