<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * GTM WooCoommerce integration.
 *
 * @package tagsyncer
 * @license GNU General Public License, version 3
 */
add_action( 'wp_enqueue_scripts', 'tagsyncer_woocommerce_enqueue_scripts' );
function tagsyncer_woocommerce_enqueue_scripts() {
    wp_enqueue_script( 'tagsyncer-script', plugin_dir_url( __FILE__ ) . '../js/tagsyncer-public.js', array( 'jquery' ), '1.0', true );

}


////////////////////////////////////////
// Purchase Event starts
///////////////////////////////////////

add_action('woocommerce_thankyou', 'tagsyncer_gtm_purchase_event');
function tagsyncer_gtm_purchase_event($order_id) {
    if (!$order_id) {
        return;
    }
    
    $order = wc_get_order($order_id);
    $currency = get_woocommerce_currency();
    $order_total = $order->get_total();
    $items = [];
    
    // Check if the customer is new (first-time buyer)
    $customer_id = $order->get_customer_id();
    $new_customer = !wc_get_customer_order_count($customer_id) > 1;

    // Get customer details
    $customer_name = $order->get_formatted_billing_full_name();
    $customer_email = $order->get_billing_email();
    $billing_address = $order->get_billing_address_1();
    $billing_city = $order->get_billing_city();
    $billing_country = $order->get_billing_country();
    $billing_postcode = $order->get_billing_postcode();
    $shipping_address = $order->get_shipping_address_1();
    $shipping_city = $order->get_shipping_city();
    $shipping_country = $order->get_shipping_country();
    $shipping_postcode = $order->get_shipping_postcode();
    
    // Loop through the order items to get the product data
    foreach ($order->get_items() as $item_id => $item) {
        $product = $item->get_product();
        $product_id = $product->get_id();
        $product_category = wp_get_post_terms($product_id, 'product_cat', array('fields' => 'names'));
        $category_name = !empty($product_category) ? $product_category[0] : 'Uncategorized';

        $items[] = [
            'item_id' => $product_id,
            'item_name' => $item->get_name(),
            'sku' => $product->get_sku() ? $product->get_sku() : $product_id,
            'price' => $product->get_price(),
            'stocklevel' => $product->get_stock_quantity(),
            'stockstatus' => $product->is_in_stock() ? 'instock' : 'outofstock',
            'google_business_vertical' => 'retail',
            'item_category' => $category_name,
            'id' => $product_id,
            'quantity' => $item->get_quantity(),
        ];
    }

    ?>
    <script type="text/javascript">
        document.addEventListener('DOMContentLoaded', function() {
            console.log('purchase script initiated');
            var purchaseData = {
                'new_customer': <?php echo esc_js($new_customer ? 'true' : 'false'); ?>,
                'event': 'purchase',
                'ecommerce': {
                    'currency': '<?php echo esc_js($currency); ?>',
                    'transaction_id': '<?php echo esc_js($order->get_order_number()); ?>',
                    'affiliation': '',
                    'value': <?php echo esc_js($order_total); ?>,
                    'tax': <?php echo esc_js($order->get_total_tax()); ?>,
                    'shipping': <?php echo esc_js($order->get_shipping_total()); ?>,
                    'coupon': '<?php echo esc_js($order->get_coupon_codes() ? implode(", ", $order->get_coupon_codes()) : ''); ?>',
                    'items': <?php echo wp_json_encode($items); ?>
                },
                'customer': {
                    'name': '<?php echo esc_js($customer_name); ?>',
                    'email': '<?php echo esc_js($customer_email); ?>',
                    'billing_address': '<?php echo esc_js($billing_address); ?>',
                    'billing_city': '<?php echo esc_js($billing_city); ?>',
                    'billing_country': '<?php echo esc_js($billing_country); ?>',
                    'billing_postcode': '<?php echo esc_js($billing_postcode); ?>',
                    'shipping_address': '<?php echo esc_js($shipping_address); ?>',
                    'shipping_city': '<?php echo esc_js($shipping_city); ?>',
                    'shipping_country': '<?php echo esc_js($shipping_country); ?>',
                    'shipping_postcode': '<?php echo esc_js($shipping_postcode); ?>'
                },
                'gtm.uniqueEventId': new Date().getTime() // Generate unique event ID
            };

            // Push the purchase event to the dataLayer
            if (window.dataLayer) {
                window.dataLayer.push(purchaseData);
            } else {
                window.dataLayer = [purchaseData];
            }
        });
    </script>
    <?php
}
////////////////////////////////////////
// Purchase Event Ends
///////////////////////////////////////
add_action( 'woocommerce_after_shop_loop_item', 'tagsyncer_add_gta_prod_data_hidden_field', 5 );
function tagsyncer_add_gta_prod_data_hidden_field() {
    global $product; static $counter = 0;
    $counter++;

    // Get product data
    $item_id = $product->get_id();
    $item_name = $product->get_name();
    $product_type = $product->get_type();
    $remarketing_id = $product->get_id();
    $product_sku = $product->get_sku();
    $product_categories = array();
    $product_brand =  $product->get_attribute('pa_brand');;
    $coupon = ''; // Placeholder for coupon
    $discount = 0; // Placeholder for discount
    $affiliation = 'Your Affiliation'; // Placeholder for affiliation
    $index = $counter; // Placeholder for index
    $currency_code = get_woocommerce_currency();

    // Get product categories
    $categories = get_the_terms( $product->get_id(), 'product_cat' );
    if ( $categories && ! is_wp_error( $categories ) ) {
        foreach ( $categories as $key => $category ) {
            $product_categories[ $key ] = $category->name;
        }
    }

    // Create the product data array
    $product_data = array(
        'item_id' => $item_id,
        'item_name' => $item_name,
        'item_brand' => $product_brand,
        'item_list_name' => 'View Product List',
        'price' => round( (float) wc_get_price_to_display( $product ), 2 ),
        'index' => $counter
    );

    // Add multiple category keys
    foreach ( $product_categories as $key => $category_name ) {
        $product_data_key = $key === 0 ? 'item_category' : 'item_category_' . ($key + 1);
        $product_data[ $product_data_key ] = $category_name;
    }
    // echo '<pre>'; var_dump($product_data); echo '</pre>';
    // Convert the product data array to JSON
    $product_data_json = wp_json_encode($product_data);
    // Output the hidden field
    echo '<input type="hidden" class="gtm_wc_prod_data" gtm_wc_price="' . esc_attr( round( (float) wc_get_price_to_display( $product ), 2 ) ) . '" gtm_wc_prod_data=\'' . esc_attr( $product_data_json ) . '\' currency_code="' . esc_attr( $currency_code ) . '">';
}

add_action( 'woocommerce_after_add_to_cart_button', 'tagsyncer_add_gtmwc_hidden_fields' );

function tagsyncer_add_gtmwc_hidden_fields() {
    global $product;

    // Get product data
    $product_id = $product->get_id();
    $product_sku = $product->get_sku();
    $product_name = $product->get_name();
    $product_categories = wp_get_post_terms($product_id, 'product_cat');

    // Check if categories are available
    if (!empty($product_categories)) {
        // Get the first category
        $product_category = $product_categories[0]->name;
    }
    $product_price = round((float) wc_get_price_to_display($product), 2);
    $product_stocklevel = $product->get_stock_quantity();
    $currency_code = get_woocommerce_currency();

    // Output hidden fields with dynamic values
    echo '<input type="hidden" name="gtmwc_id" value="' . esc_attr($product_id) . '">';
    echo '<input type="hidden" name="gtmwc_internal_id" value="' . esc_attr($product_id) . '">';
    echo '<input type="hidden" name="gtmwc_name" value="' . esc_attr($product_name) . '">';
    echo '<input type="hidden" name="gtmwc_sku" value="' . esc_attr($product_sku) . '">';
    echo '<input type="hidden" name="gtmwc_category" value="' . esc_attr($product_category) . '">';
    echo '<input type="hidden" name="gtmwc_price" value="' . esc_attr($product_price) . '">';
    echo '<input type="hidden" name="gtmwc_stocklevel" value="' .esc_attr($product_stocklevel) . '">';
    echo '<input type="hidden" name="currency_code" value="' . esc_attr($currency_code) . '">';
}

function tagsyncer_my_custom_output_cart_data_to_header() {
    // Ensure WooCommerce is active
    if (class_exists('WooCommerce') && is_cart() || is_checkout()) {
        // Get cart contents
        $cart = WC()->cart->get_cart();
        $currency_code = get_woocommerce_currency();

        // var_dump($currency_code);
        
        // Initialize an array to hold cart items data
        $cart_items_data = array();
        $product_categories = array();
        
        // Loop through each cart item
        foreach ($cart as $cart_item_key => $cart_item) {
            // Get product data
            $product = $cart_item['data'];
            
            // Initialize an array to hold product data
            $product_data = array(
                'item_id' => $product->get_id(),
                'item_name' => $product->get_name(),
                'quantity' => $cart_item['quantity'],
                'currency' => get_woocommerce_currency(),
                'price' => wc_get_price_excluding_tax($product), // Adjust as needed
                'total_price' => wc_get_price_excluding_tax($product) * $cart_item['quantity'], // Adjust as needed
                // Add more data as needed
            );
            
            // Check if the product is a variation
            if ($product->is_type('variation')) {
                // Get variation attributes
                $variation_attributes = $product->get_variation_attributes();
                // Initialize an empty array to store variant names
                $variant_names = array();

                // Loop through variation attributes to extract variant names
                foreach ($variation_attributes as $attribute_name => $attribute_value) {
                    // Add the variant name to the array
                    $variant_names[] = $attribute_value;
                }

                $variant_names_string = implode(', ', $variant_names);

                // Add variant names to the product data
                $product_data['variant_names'] = $variant_names_string;
            }

            // Get product categories
            $categories = get_the_terms( $product->get_id(), 'product_cat' );
            if ( $categories && ! is_wp_error( $categories ) ) {
                foreach ( $categories as $key => $category ) {
                    $product_categories[ $key ] = $category->name;
                }
            }
            // Add multiple category keys
            foreach ( $product_categories as $key => $category_name ) {
                $product_data_key = $key === 0 ? 'item_category' : 'item_category_' . ($key + 1);
                $product_data[ $product_data_key ] = $category_name;
            }
            
            // Get product brand (if available)
            $product_brand = $product->get_attribute('pa_brand'); // Adjust as needed
            if (!empty($product_brand)) {
                // Add brand to the product data
                $product_data['brand'] = $product_brand;
            }
            
            // Add product data to the array
            $cart_items_data[] = $product_data;
        }
        // Convert the array to JSON
        $cart_items_json = wp_json_encode($cart_items_data);
        
        // Output the cart data directly into a <script> tag in the WordPress header
        echo '<script>';
        echo 'var cartAndCurrencyData = {';
        echo '"cartData": ' . $cart_items_json . ',';
        echo '"gtmCurrency": "' . esc_attr($currency_code) . '"';
        echo '};'; 
        echo '</script>';
    }
}
add_action('wp_head', 'tagsyncer_my_custom_output_cart_data_to_header');


add_action( 'woocommerce_cart_item_name', 'tagsyncer_add_gta_prod_data_hidden_field_in_cart', 10, 3 );

function tagsyncer_add_gta_prod_data_hidden_field_in_cart( $product_name, $cart_item, $cart_item_key ) {
    // Get product data
    $product = $cart_item['data'];
    $item_id = $product->get_id();
    $item_name = $product->get_name();
    $product_type = $product->get_type();
    $product_sku = $product->get_sku();
    $product_categories = array();
    $product_brand = $product->get_attribute('pa_brand'); // Assuming the brand is stored as a product attribute named 'pa_brand'
    $currency_code = get_woocommerce_currency();

    // Get product categories
    $categories = get_the_terms( $product->get_id(), 'product_cat' );
    if ( $categories && ! is_wp_error( $categories ) ) {
        foreach ( $categories as $key => $category ) {
            $product_categories[ $key ] = $category->name;
        }
    }

    // Check if the product is a variation
    if ($product->is_type('variation')) {
        // Get variation attributes
        $variation_attributes = $product->get_variation_attributes();
        // Initialize an empty array to store variant names
        $variant_names = array();

        // Loop through variation attributes to extract variant names
        foreach ($variation_attributes as $attribute_name => $attribute_value) {
            // Add the variant name to the array
            $variant_names[] = $attribute_value;
        }

        $variant_names_string = implode(', ', $variant_names);

        // Add variant names to the product data
        $product_data['variant_names'] = $variant_names_string;
    }

    // Create the product data array
    $product_data = array(
        'item_id' => $item_id,
        'item_name' => $item_name,
        'item_brand' => $product_brand,
        'price' => round( (float) $product->get_price(), 2 ),
        'variation' => $variation_data, 
    );

    // Add multiple category keys
    foreach ( $product_categories as $key => $category_name ) {
        $product_data_key = $key === 0 ? 'item_category' : 'item_category_' . ($key + 1);
        $product_data[ $product_data_key ] = $category_name;
    }

    // Convert the product data array to JSON
    $product_data_json = wp_json_encode($product_data);

    // Output the hidden field within the table structure for each cart item
    echo '<input type="hidden" class="removed_item_data" gtm_wc_price="' . esc_attr( round( (float) $product->get_price(), 2 ) ) . '" removed_item_data=\'' . esc_attr( $product_data_json ) . '\' currency_code="' . esc_attr( $currency_code ) . '">';

    return $product_name;
}