(function( $ ) {
	'use strict';


	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	jQuery(document).ready(function() {
		console.log('Elementor GTM tracking is active.');

		////////////////////////////////////
		// elementor form submission trigger
		////////////////////////////////////

		$(document).on('submit', '.elementor-form', function(e) {
			console.log("Form submitted");

			// Initialize an object to hold the form data
			var formData = {};

			// Loop through all the form fields and capture their names and values
			$(this).find('input, select, textarea').each(function() {
				var fieldName = $(this).attr('name') || $(this).attr('id');
				var fieldValue = $(this).val();
				if (fieldName) {
					formData[fieldName] = fieldValue;
				}
			});

			// Build the data layer event object
			var eventData = {
				event: "elementor_form_submission",
				form_name: $(this).attr('name') || "Unnamed Form", // Get form name dynamically
				form_data: formData
			};

			// Retrieve all data layers dynamically
			var dataLayerNames = Object.keys(window).filter(function(key) {
				// Identify potential data layers based on naming convention and type
				return key.startsWith('dataLayer') && Array.isArray(window[key]);
			});
			
			// Push the event data to each dynamically identified data layer
			dataLayerNames.forEach(function(layerName) {
				window[layerName].push(eventData);
				console.log("Data pushed to " + layerName + ":", eventData);
			});
		});

		//////////////////////////////////////////////
		// elementor form submission trigger ends here
		//////////////////////////////////////////////
	});
})( jQuery );
