(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */
	jQuery(document).ready(function(){
		console.log('wc gtm events are active');


		function pushToAllDataLayers(data) {
			// Check for available data layers in the window object
			const dataLayerNames = Object.keys(window).filter(key => key.includes('dataLayer'));
			console.log(dataLayerNames);
			// Push the data to all available data layers
			dataLayerNames.forEach(layer => {
				if (window[layer]) {
					window[layer].push(data);
				}
			});
		}

		if ( document.querySelectorAll( '.gtm_wc_prod_data' ).length > 0 ) {
			let items = [];
			let ga4_products = [];
			let currencyCode = 0;
			let product_data;
			document.querySelectorAll( '.gtm_wc_prod_data' ).forEach( function( dom_productdata ) {
				product_data = JSON.parse(dom_productdata.getAttribute('gtm_wc_prod_data'));
				currencyCode = dom_productdata.getAttribute('currency_code');
				items.push(product_data);
				
			});
			console.log(currencyCode);
			console.log(items);
			window.dataLayer = window.dataLayer || [];
			pushToAllDataLayers({
				'event' : 'view_item_list',
				'ecommerce': {
					'currencyCode': currencyCode,
					items
				}
			});
			// Assuming product links have a common class, e.g., '.product-link'
			jQuery(document).on('click', '.product a', function(event) {
				var prod_data_sel = jQuery(this).closest('.product').find('.gtm_wc_prod_data');
				var items = JSON.parse(prod_data_sel.attr('gtm_wc_prod_data'));
				var curr_code = prod_data_sel.attr('currency_code');
				
				// Push select_item event to dataLayer
				window.dataLayer = window.dataLayer || [];
				window.dataLayer.push({
					'event' : 'select_item',
					'ecommerce': {
						'currencyCode': curr_code,
						items
					}
				});
			});

		}
		// Check if the product data exists on the page
		if ($('body').hasClass('single-product')) {

			// Get the values from the hidden fields
			var productId = $('input[name="gtmwc_id"]').val();
			var productName = $('input[name="gtmwc_name"]').val();
			var productSku = $('input[name="gtmwc_sku"]').val();
			var productCategory = $('input[name="gtmwc_category"]').val();
			var productPrice = $('input[name="gtmwc_price"]').val();
			var productStocklevel = $('input[name="gtmwc_stocklevel"]').val();
			var variationIds = $('input[name="variation_id"]').val();
			var currency_code = $('input[name="currency_code"]').val(); 
			// Push the view_item event to the data layer
			window.dataLayer = window.dataLayer || [];
			window.dataLayer.push({
				'event': 'view_item',
				'ecommerce': {
					'currencyCode': currency_code, // Example currency code, replace with your currency code
					'items': [{
						'item_id': productId,
						'item_name': productName,
						'item_category': productCategory,
						'item_price': productPrice,
						'item_list_name': productCategory, 
						'variation_id': variationIds 
					}]
				}
			});
			jQuery(document).on('found_variation', function(event, variation) {
				var variation_attributes = variation.attributes; // Get variation attributes
				var variation_values = [];

				// Loop through variation attributes to extract values
				for (var key in variation_attributes) {
					if (variation_attributes.hasOwnProperty(key)) {
						var value = variation_attributes[key];
						variation_values.push(value);
					}
				}

				// Join variation values into a string
				var variation_string = variation_values.join(' , ');

				var var_price = variation.display_price; 
				var product_id = $('input[name="gtmwc_id"]').val(); 
				var internal_id = $('input[name="gtmwc_internal_id"]').val(); 
				var product_name = $('input[name="gtmwc_name"]').val(); 
				var product_sku = $('input[name="gtmwc_sku"]').val(); 
				var product_category = $('input[name="gtmwc_category"]').val(); 
				var product_price = $('input[name="gtmwc_price"]').val(); 
				var product_stocklevel = $('input[name="gtmwc_stocklevel"]').val(); 
				var currency_code = $('input[name="currency_code"]').val(); 
				var variationIds = $('input[name="variation_id"]').val(); 
				window.dataLayer = window.dataLayer || [];
				window.dataLayer.push({
					'event': 'view_item',
					'ecommerce': {
						'currencyCode': currency_code, 
						'value': var_price,
						'items': [{
							'item_id': productId,
							'item_name': productName,
							'item_variant': variation_string,
							'item_category': productCategory,
							'item_price': var_price,
							'item_list_name': productCategory, 
							'variation_id': variationIds 
						}]
					}
				});
		
			});
			
			$(document.body).on('added_to_cart', function(event, fragments, cart_hash, button) {

			});
		}

		document.addEventListener( 'click', function( e ) {
			let event_target_element = e.target;

			if ( !event_target_element ) {
				// for some reason event target is not specificed
				return true;
			}

			try {
				if ( !event_target_element.closest( '.add_to_cart_button:not(.product_type_variable, .product_type_grouped, .single_add_to_cart_button)' ) ) {
					return true;
				}
			} catch (e) {
				// during beta testing, closest() sometimes threw SyntaxError which is thrown if selector is invalid. But the selector above should be valid in all cases
				// assumption was that perhaps event_target_element was not set or not a proper DOM node for some reasons
				return true;
			}

			const product_el = event_target_element.closest( '.product,.wc-block-grid__product' );
			var productdata = product_el && product_el.querySelector( '.gtm_wc_prod_data' );
			if ( !productdata ) {
				return true;
			}
			var pdata = JSON.parse(productdata.getAttribute('gtm_wc_prod_data'));
			var currencyCode = productdata.getAttribute('currency_code');
			var pprice = productdata.getAttribute('gtm_wc_price');
			console.log(currencyCode);
			window.dataLayer = window.dataLayer || [];
			window.dataLayer.push({
				'event' : 'add_to_cart',
				'ecommerce': {
					'currencyCode': currencyCode,
					'value': pprice,
					'item': { pdata }
				}
			});
		});
		// Assuming you have an event or method that's triggered when a product variation is selected and added to the cart,
// such as selecting a variation and clicking an "Add to Cart" button.

// For example, assuming a button with class "add-to-cart-btn" triggers the addition of a product to the cart:
	jQuery(document).on('click', '.single_add_to_cart_button:not(.disabled)', function(event) {

		// Get product information from the DOM
		var product_id = $('input[name="gtmwc_id"]').val(); 
		var product_name = $('input[name="gtmwc_name"]').val(); 
		var product_category = $('input[name="gtmwc_category"]').val(); 
		var currency_code = $('input[name="currency_code"]').val(); 
		var variationIds = $('input[name="variation_id"]').val(); 

		// Get variation information
		var variation_string = ''; // Initialize variation string
		var variation_values = []; // Array to store variation values

		$('.variations select').each(function() {
			variation_values.push($(this).val()); // Push selected variation values to array
		});
		variation_string = variation_values.join(' , '); // Join variation values into a string

		// Get quantity
		var quantity = parseInt($('input[name="quantity"]').val()) || 1; // Default quantity to 1 if not provided

		// Calculate total price based on quantity
		var product_price_per_unit = parseFloat($('input[name="gtmwc_price"]').val());
		var total_price = product_price_per_unit * quantity;
		
		// Push add_to_cart event to dataLayer
		window.dataLayer = window.dataLayer || [];
		window.dataLayer.push({
			'event': 'add_to_cart',
			'ecommerce': {
				'currencyCode': currency_code, 
				'value': total_price.toFixed(2),
				'items': [{
					'item_id': product_id,
					'item_name': product_name,
					'item_variant': variation_string,
					'item_category': product_category,
					'item_price': total_price.toFixed(2),
					'item_list_name': productCategory, 
					'quantity': quantity,
					'variation_id': variationIds 
				}]
			}
		});
	});

	// Your JavaScript file
	if (typeof cartAndCurrencyData !== 'undefined') {
		var cartItems = cartAndCurrencyData.cartData;
		var gtmCurrency = cartAndCurrencyData.gtmCurrency;

		console.log(gtmCurrency);
		// Check if there are items in the cart
		if (cartItems.length > 0 && document.body.classList.contains('woocommerce-cart')) {
			// Initialize an array to hold product data

			// Initialize total value of the cart
			var cartTotal = 0;

			// Loop through each item in the cart
			cartItems.forEach(function(item) {

				// Calculate total value of the cart
				cartTotal += parseFloat(item.total_price);

			});

			// Construct the event object with the products array and cart total
			var eventData = {
				'event': 'view_cart',
				'ecommerce': {
					'currencyCode': gtmCurrency, 
					'value': cartTotal.toFixed(2),
					'items': cartItems,
					
				}
			};

			// Push the event object to the data layer
			if (window.dataLayer) {
				dataLayer.push(eventData);
			} else {
				// If data layer is not available, create it and push the data
				window.dataLayer = [eventData];
			}
		} else if (cartItems.length > 0 && document.body.classList.contains('woocommerce-checkout')) {
			// Initialize an array to hold product data

			// Initialize total value of the cart
			var cartTotal = 0;

			// Loop through each item in the cart
			cartItems.forEach(function(item) {

				// Calculate total value of the cart
				cartTotal += parseFloat(item.total_price);

			});

			// Construct the event object with the products array and cart total
			var eventData = {
				'event': 'begin_checkout',
				'ecommerce': {
					'currencyCode': gtmCurrency, 
					'value': cartTotal.toFixed(2),
					'items': cartItems,
					
				}
			};

			// Push the event object to the data layer
			if (window.dataLayer) {
				dataLayer.push(eventData);
			} else {
				// If data layer is not available, create it and push the data
				window.dataLayer = [eventData];
			}
		} else {}
	}


		if ($('body').hasClass('woocommerce-cart')) {
			$(document).on('click', 'a.remove', function(e) {
				var cart_item = jQuery(this).closest('.cart_item');
				var item_data_selector = jQuery(cart_item).find('.removed_item_data');
				var item_price = item_data_selector.attr('gtm_wc_price');
				var item_curr = item_data_selector.attr('currency_code');
				var item_data = JSON.parse(item_data_selector.attr('removed_item_data'));

				alert(item_data);

				var eventData = {
					'event': 'remove_from_cart',
					'ecommerce': {
						'currencyCode': item_curr, 
						'value': item_price,
						'items': item_data,
					}
				};

				if (window.dataLayer) {
					dataLayer.push(eventData);
				} else {
					window.dataLayer = [eventData];
				}

			});

			function gtmwp_handle_cart_qty_change() {
				document.querySelectorAll( '.product-quantity input.qty' ).forEach(function( qty_el ) {
					const original_value = qty_el.defaultValue;
			
					let current_value  = parseInt( qty_el.value );
					if ( isNaN( current_value ) ) {
						current_value = original_value;
					}
			
					// is quantity changed changed?
					if ( original_value != current_value ) {
						const cart_item_temp = qty_el.closest( '.cart_item' );
						const productdata = cart_item_temp && cart_item_temp.querySelector( '.removed_item_data' );
						if ( !productdata ) {
							return;
						}
			
						let productprice = productdata.getAttribute( 'gtm_wc_price' );
						var curr = productdata.getAttribute( 'currency_code' );
						if ( typeof productprice == "string" ) {
							productprice = parseFloat( productprice );
							if ( isNaN( productprice ) ) {
								productprice = 0;
							}
						} else if ( typeof productprice != "number" ) {
							productprice = 0;
						}
			
						// does the quantity increase?
						if ( original_value < current_value ) {
							// yes => handle add to cart event
							var prod_data = JSON.parse(productdata.getAttribute( 'removed_item_data' ));
							var eventData = {
								'event': 'add_to_cart',
								'ecommerce': {
									'currencyCode': curr, 
									'value': productprice,
									'items': prod_data,
								}
							};
							pushToAllDataLayers(eventData)
							// if (window.dataLayer) {
							// 	dataLayer.push(eventData);
							// } else {
							// 	window.dataLayer = [eventData];
							// }
							
						} else {
							// no => handle remove from cart event
							var prod_data = JSON.parse(productdata.getAttribute( 'removed_item_data' ));
			
							var eventData = {
								'event': 'remove_from_cart',
								'ecommerce': {
									'currencyCode': curr, 
									'value': productprice,
									'items': prod_data,
								}
							};
							pushToAllDataLayers(eventData)
							// if (window.dataLayer) {
							// 	dataLayer.push(eventData);
							// } else {
							// 	window.dataLayer = [eventData];
							// }
						}
					} // end if qty changed
				}); // end each qty field
			} 

			document.addEventListener( 'click', function( e ) {
				let event_target_element = e.target;
	
				if ( !event_target_element ) {
					// for some reason event target is not specificed
					return true;
				}
	
				if ( !event_target_element.closest( '[name=update_cart]' ) ) {
					return true;
				}
	
				gtmwp_handle_cart_qty_change();
			});
	
			document.addEventListener( 'keypress', function( e ) {
				let event_target_element = e.target;
	
				if ( !event_target_element ) {
					// for some reason event target is not specificed
					return true;
				}
	
				if ( !event_target_element.closest( '.woocommerce-cart-form input[type=number]' ) ) {
					return true;
				}
	
				gtmwp_handle_cart_qty_change();
			});
			
		}
		
		
		// alert();
		// $('body').on('click', '.add_to_cart_button:not(.single_add_to_cart_button)', function() {
		// 	alert();
		// });
		


		/////////////////////////////////////
		// add_shipping_info event starts here
		/////////////////////////////////////
		// Function to extract the selected shipping method from the checkout page
		function getSelectedShippingMethod() {
			// Target the checked radio input under the shipping method fieldset
			var selectedMethod = $('#shipping-option input[type="radio"]:checked').val();
	
			// If a shipping method is selected, return its value (e.g., 'flat_rate:2')
			return selectedMethod ? selectedMethod : null;
		}
	
		// Listen for checkout updates
		$(document.body).on('updated_checkout', function() {
			// Get the selected shipping method
			var shippingMethod = getSelectedShippingMethod();
	
			// Ensure cart data and shipping method are available
			if (typeof cartAndCurrencyData !== 'undefined' && shippingMethod) {
				var cartItems = cartAndCurrencyData.cartData;
				var gtmCurrency = cartAndCurrencyData.gtmCurrency;
				
	
				// Calculate total value of the cart
				var cartTotal = 0;
				cartItems.forEach(function(item) {
					cartTotal += parseFloat(item.total_price);
				});
	
				// Construct the event object for add_shipping_info
				var eventData = {
					'event': 'add_shipping_info',
					'ecommerce': {
						'currencyCode': gtmCurrency,
						'value': cartTotal.toFixed(2), // Total value of the cart
						'shipping_tier': shippingMethod, // Selected shipping method
						'items': cartItems
					}
				};
				

				// Push the event object to the data layer
				pushToAllDataLayers(eventData)

			}
		});
	
		// Also trigger on radio button change for immediate updates
		$(document).on('change', '#shipping-option input[type="radio"]', function() {

			console.log("Shipping option changed"); // Debug: check if event listener is working
			// Get the selected shipping method
			var shippingMethod = getSelectedShippingMethod();
	
			// Ensure cart data and shipping method are available
			if (typeof cartAndCurrencyData !== 'undefined' && shippingMethod) {
				var cartItems = cartAndCurrencyData.cartData;
				var gtmCurrency = cartAndCurrencyData.gtmCurrency;

	
				// Calculate total value of the cart
				var cartTotal = 0;
				cartItems.forEach(function(item) {
					cartTotal += parseFloat(item.total_price);
				});
	
				// Construct the event object for add_shipping_info
				var eventData = {
					'event': 'add_shipping_info',
					'ecommerce': {
						'currencyCode': gtmCurrency,
						'value': cartTotal.toFixed(2),
						'shipping_tier': shippingMethod,
						'items': cartItems
					}
				};

				pushToAllDataLayers(eventData)
	
				// Push the event object to the data layer
				// if (window.dataLayer) {
				// 	window.dataLayer.push(eventData);
				// } else {
				// 	window.dataLayer = [eventData];
				// }

			}
		});


		////////////////////////////////////
		// add_shipping_info event ends here
		/////////////////////////////////////








		///////////////////////////////
		// add_payment_info starts here
		//////////////////////////////

		 // Function to extract the selected payment method from the checkout page
		 function getSelectedPaymentMethod() {
			// Target the checked radio input under the payment method section
			var selectedMethod = $('input[name="payment_method"]:checked').val();
			return selectedMethod ? selectedMethod : null;
		}
	
		// Listen for checkout updates and payment method changes
		$(document.body).on('updated_checkout', function() {
			// Get the selected payment method
			var paymentMethod = getSelectedPaymentMethod();
	
			// Ensure cart data and payment method are available
			if (typeof cartAndCurrencyData !== 'undefined' && paymentMethod) {
				var cartItems = cartAndCurrencyData.cartData;
				var gtmCurrency = cartAndCurrencyData.gtmCurrency;
	
				// Calculate total value of the cart
				var cartTotal = 0;
				cartItems.forEach(function(item) {
					cartTotal += parseFloat(item.total_price);
				});
	
				// Construct the event object for add_payment_info
				var eventData = {
					'event': 'add_payment_info',
					'ecommerce': {
						'currencyCode': gtmCurrency,
						'value': cartTotal.toFixed(2), // Total value of the cart
						'payment_type': paymentMethod, // Selected payment method
						'items': cartItems
					}
				};
				pushToAllDataLayers(eventData)
				// Push the event object to the data layer
				// if (window.dataLayer) {
				// 	window.dataLayer.push(eventData);
				// } else {
				// 	window.dataLayer = [eventData];
				// }
			}
		});
	
		// Also trigger on payment method change for immediate updates
		$('form.woocommerce-checkout').on('change', 'input[name=payment_method]', function() {
			console.log('payment info trigger')
			// Get the selected payment method
			var paymentMethod = getSelectedPaymentMethod();
	
			// Ensure cart data and payment method are available
			if (typeof cartAndCurrencyData !== 'undefined' && paymentMethod) {
				var cartItems = cartAndCurrencyData.cartData;
				var gtmCurrency = cartAndCurrencyData.gtmCurrency;
	
				// Calculate total value of the cart
				var cartTotal = 0;
				cartItems.forEach(function(item) {
					cartTotal += parseFloat(item.total_price);
				});
	
				// Construct the event object for add_payment_info
				var eventData = {
					'event': 'add_payment_info',
					'ecommerce': {
						'currencyCode': gtmCurrency,
						'value': cartTotal.toFixed(2),
						'payment_type': paymentMethod,
						'items': cartItems
					}
				};
	
				// Push the event object to the data layer

				pushToAllDataLayers(eventData)

				// if (window.dataLayer) {
				// 	window.dataLayer.push(eventData);
				// } else {
				// 	window.dataLayer = [eventData];
				// }
			}
		});	

		/////////////////////////////
		// add_payment_info ends here
		/////////////////////////////



		
	});
})( jQuery );

