<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.tagsyncer.com/
 * @since             1.0.0
 * @package           tagsyncer
 *  

 * @wordpress-plugin
 * Plugin Name:       TagSyncer – Free Google Tag Manager Plugin for WordPress
 * Plugin URI:        https://www.tagsyncer.com/
 * Description:       Easily integrate Google Tag Manager with tracking for scroll events, forms, and WooCommerce, all manageable from the WordPress dashboard.
 * Version:           1.1.0
 * Author:            Involvz
 * Author URI:        https://involvz.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       tag-syncer
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'TagSyncer_VERSION', '1.0.0' );
$GLOBALS['tagsyncer_datalayer_data'] = array();

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-tagsyncer-activator.php
 */
function tagsyncer_activate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-tagsyncer-activator.php';
	tagsyncer_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-tagsyncer-deactivator.php
 */
function tagsyncer_deactivate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-tagsyncer-deactivator.php';
	tagsyncer_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'tagsyncer_activate' );
register_deactivation_hook( __FILE__, 'tagsyncer_deactivate' );
/**
 * Adds an action to declare compatibility with High Performance Order Storage (HPOS)
 * before WooCommerce initialization.
 *
 * @since 1.17
 *
 * @param string   $hook_name  The name of the action to which the callback function is hooked.
 * @param callable $callback   The callback function to be executed when the action is run.
 * @param int      $priority   Optional. The order in which the callback functions are executed. Default is 10.
 * @param int      $args_count Optional. The number of arguments the callback accepts. Default is 1.
 *
 * @return void
 */
add_action(
	'before_woocommerce_init',
	function() {
		// Check if the FeaturesUtil class exists in the \Automattic\WooCommerce\Utilities namespace.
		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			// Declare compatibility with custom order tables using the FeaturesUtil class.
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	}
);


// Add a "Settings" link to the plugin actions on the Plugins page
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'tagsyncer_add_settings_link');

function tagsyncer_add_settings_link($links) {
    // Define the URL for the settings page
    $settings_url = site_url('/wp-admin/admin.php?page=google-tag-manager-settings'); 
    $settings_link = '<a href="' . esc_url($settings_url) . '">' . __('Settings', 'tag-syncer') . '</a>';

    // Add the Settings link to the existing links
    array_unshift($links, $settings_link);

    return $links;
}




/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-tagsyncer.php';
// add_action('init', 'my_plugin_woocommerce_support');
// function my_plugin_woocommerce_support() {
//     // Check if WooCommerce is active
//     if (class_exists('WooCommerce')) {
//         // Call WooCommerce's plugins_loaded function
//         add_action('plugins_loaded', 'woocommerce_loaded');
//     }
// }

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function tagsyncer_run() {

	$plugin = new tagsyncer();
	$plugin->run();

}
tagsyncer_run();
